@@ -781,6 +781,8 @@ cholmod_sparse* M_cholmod_speye(size_t nrow, size_t ncol,
 				int xtype, cholmod_common *Common);
 cholmod_sparse* M_cholmod_transpose(cholmod_sparse *A, int values,
 				    cholmod_common *Common);
+cholmod_sparse* M_cholmod_vertcat(cholmod_sparse *A, cholmod_sparse *B,
+				  int values, cholmod_common *Common);
 cholmod_sparse* M_cholmod_copy(cholmod_sparse *A, int stype,
 			       int mode, cholmod_common *Common);
 cholmod_sparse* M_cholmod_add(cholmod_sparse *A, cholmod_sparse *B,
