@@ -18,10 +18,10 @@ assert.EQ.mat( crossprod(rep(1,5), m.),  rbind( colSums(m5)))
 assert.EQ.mat( crossprod(m5, rep(1,5)),  cbind( colSums(m5)))
 assert.EQ.mat( crossprod(m., rep(1,5)),  cbind( colSums(m5)))
 
-## classes differ; but the 'dimnames' are *both* missing -- FIXME
-tc.m5 <- m5 %*% t(m5)
-(tcm5 <- tcrossprod(m5)) # "dpo*"
-assert.EQ.mat(tc.m5, mm5 <- as(tcm5, "matrix"))# missing dimnames - FIXME
+## classes differ
+tc.m5 <- m5 %*% t(m5)    # "dge*", no dimnames (FIXME)
+(tcm5 <- tcrossprod(m5)) # "dpo*"  w/ dimnames
+assert.EQ.mat(tc.m5, mm5 <- as(tcm5, "matrix"))
 ## tcrossprod(x,y) :
 assert.EQ.mat(tcrossprod(m5, m5), mm5)
 assert.EQ.mat(tcrossprod(m5, as(m5,"matrix")), mm5)
@@ -85,7 +85,9 @@ N <- 10
 nrFT <- nrow(fromTo)
 rowi <- rep.int(1:nrFT, fromTo[,2]-fromTo[,1] + 1) - 1:1
 coli <- unlist(lapply(1:nrFT, function(x) fromTo[x,1]:fromTo[x,2])) - 1:1
-sM  <- new("lgTMatrix", i = rowi, j=coli, Dim=as.integer(c(N,N)))
+
+## "n" --- nonzero pattern Matrices
+sM  <- new("ngTMatrix", i = rowi, j=coli, Dim=as.integer(c(N,N)))
 sM # nice
 
 sm <- as(sM, "matrix")
@@ -95,12 +97,29 @@ assert.EQ.mat(t(sM) %*% sM,
               (t(sm) %*% sm) > 0, tol=0)
 crossprod(sM)
 tcrossprod(sM)
-stopifnot(identical(as( crossprod(sM), "lgCMatrix"), t(sM) %*%   sM),
-          identical(as(tcrossprod(sM), "lgCMatrix"),  sM  %*% t(sM)))
+stopifnot(identical(as( crossprod(sM), "ngCMatrix"), t(sM) %*%   sM),
+          identical(as(tcrossprod(sM), "ngCMatrix"),  sM  %*% t(sM)))
 
 assert.EQ.mat( crossprod(sM),  crossprod(sm) > 0)
 assert.EQ.mat(tcrossprod(sM), as(tcrossprod(sm),"matrix") > 0)
 
+## "l" --- logical Matrices -- use usual 0/1 arithmetic
+nsM <- sM
+sM  <- as(sM, "lMatrix")
+sm <- as(sM, "matrix")
+stopifnot(identical(sm, as.matrix(nsM)))
+sM %*% sM
+assert.EQ.mat(sM %*% sM,        sm %*% sm)
+assert.EQ.mat(t(sM) %*% sM,
+              t(sm) %*% sm, tol=0)
+crossprod(sM)
+tcrossprod(sM)
+stopifnot(identical( crossprod(sM), as(t(sM) %*% sM, "dsCMatrix")),
+          identical(tcrossprod(sM), as(sM %*% t(sM), "dsCMatrix")))
+assert.EQ.mat( crossprod(sM),  crossprod(sm))
+assert.EQ.mat(tcrossprod(sM), as(tcrossprod(sm),"matrix"))
+
+
 ## A sparse example - with *integer* matrix:
 M <- Matrix(cbind(c(1,0,-2,0,0,0,0,0,2.2,0),
                   c(2,0,0,1,0), 0, 0, c(0,0,8,0,0),0))
@@ -113,6 +132,7 @@ MM. <- tcrossprod(M)
 stopifnot(class(MM.) == "dsCMatrix",
           class(M.M) == "dsCMatrix")
 
+
 ## even simpler
 m <- matrix(0, 4,7); m[c(1, 3, 6, 9, 11, 22, 27)] <- 1
 (mm <- Matrix(m))
